==> 1.0.39.tar.gz: lib/modules/account/user_address_model.dart <==
List<UserAddressModel> userByAddressFromJson(dynamic str) =>
    List<UserAddressModel>.from(str.map((x) => UserAddressModel.fromJson(x)));

class UserAddressModel {
  late final String sId;
  late final String? companyName;
  late final String? contactName;
  late final String? emailId;
  late final String? address;
  late final String? mobileNumber;
  late final String? pinCode;
  late final String? country;
  late final String? state;
  late final String? city;
  late final bool billingAddress;
  late final String sTypename;

  UserAddressModel(
      {required this.sId,
      required this.companyName,
      required this.contactName,
      required this.emailId,
      required this.address,
      required this.mobileNumber,
      required this.pinCode,
      required this.country,
      required this.state,
      required this.city,
      required this.billingAddress,
      required this.sTypename});

  UserAddressModel.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    companyName = json['companyName'];
    contactName = json['contactName'];
    emailId = json['emailId'];
    address = json['address'];
    mobileNumber = json['mobileNumber'];
    pinCode = json['pinCode'];
    country = json['country'];
    state = json['state'];
    city = json['city'];
    billingAddress = json['billingAddress'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['companyName'] = this.companyName;
    data['contactName'] = this.contactName;
    data['emailId'] = this.emailId;
    data['address'] = this.address;
    data['mobileNumber'] = this.mobileNumber;
    data['pinCode'] = this.pinCode;
    data['country'] = this.country;
    data['state'] = this.state;
    data['city'] = this.city;
    data['billingAddress'] = this.billingAddress;
    data['__typename'] = this.sTypename;
    return data;
  }
}

==> 1.0.50.tar.gz: lib/modules/account/user_address_model.dart <==
List<UserAddressModel> userByAddressFromJson(dynamic str) =>
    List<UserAddressModel>.from(str.map((x) => UserAddressModel.fromJson(x)));

class UserAddressModel {
  late final String? sId;
  late final String? companyName;
  late final String? contactName;
  late final String? emailId;
  late final String? address;
  late final String? mobileNumber;
  late final String? pinCode;
  late final String? country;
  late final String? state;
  late final String? city;
  late final bool billingAddress;
  late final String? sTypename;

  UserAddressModel(
      {required this.sId,
      required this.companyName,
      required this.contactName,
      required this.emailId,
      required this.address,
      required this.mobileNumber,
      required this.pinCode,
      required this.country,
      required this.state,
      required this.city,
      required this.billingAddress,
      required this.sTypename});

  UserAddressModel.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    companyName = json['companyName'];
    contactName = json['contactName'];
    emailId = json['emailId'];
    address = json['address'];
    mobileNumber = json['mobileNumber'];
    pinCode = json['pinCode'];
    country = json['country'];
    state = json['state'];
    city = json['city'];
    billingAddress = json['billingAddress'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['companyName'] = this.companyName;
    data['contactName'] = this.contactName;
    data['emailId'] = this.emailId;
    data['address'] = this.address;
    data['mobileNumber'] = this.mobileNumber;
    data['pinCode'] = this.pinCode;
    data['country'] = this.country;
    data['state'] = this.state;
    data['city'] = this.city;
    data['billingAddress'] = this.billingAddress;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class UpdateBillingAddressRequestModel {
  late final String sId;
  late final String addressId;
  late final UpdateBillingAddressInput addressInput;

  UpdateBillingAddressRequestModel(
      {required this.sId, required this.addressId, required this.addressInput});
}

class UpdateBillingAddressInput {
  late final bool billingAddress;
  UpdateBillingAddressInput({required this.billingAddress});

  UpdateBillingAddressInput.fromJson(Map<String, dynamic> json) {
    billingAddress = json['billingAddress'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['billingAddress'] = this.billingAddress;

    return data;
  }
}

class UpdateAddAddressRequestModel {
  late final String sId;
  late final String? addressId;
  late final UserAddressRequestModel? addressInput;

  UpdateAddAddressRequestModel(
      {required this.sId, this.addressId, this.addressInput});
}

// class UpdateAddressRequestModel {
//   late final String sId;
//   late final String addressId;
//   late final UserAddressModel addressInput;

//   UpdateAddressRequestModel(
//       {required this.sId, required this.addressId, required this.addressInput});
// }

class UserAddressRequestModel {
  late final String? companyName;
  late final String? contactName;
  late final String? emailId;
  late final String? address;
  late final String? mobileNumber;
  late final String? pinCode;
  late final String? country;
  late final String? state;
  late final String? city;
  late final bool billingAddress;

  UserAddressRequestModel({
    required this.companyName,
    required this.contactName,
    required this.emailId,
    required this.address,
    required this.mobileNumber,
    required this.pinCode,
    required this.country,
    required this.state,
    required this.city,
    required this.billingAddress,
  });

  UserAddressRequestModel.fromJson(Map<String, dynamic> json) {
    companyName = json['companyName'];
    contactName = json['contactName'];
    emailId = json['emailId'];
    address = json['address'];
    mobileNumber = json['mobileNumber'];
    pinCode = json['pinCode'];
    country = json['country'];
    state = json['state'];
    city = json['city'];
    billingAddress = json['billingAddress'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['companyName'] = this.companyName;
    data['contactName'] = this.contactName;
    data['emailId'] = this.emailId;
    data['address'] = this.address;
    data['mobileNumber'] = this.mobileNumber;
    data['pinCode'] = this.pinCode;
    data['country'] = this.country;
    data['state'] = this.state;
    data['city'] = this.city;
    data['billingAddress'] = this.billingAddress;
    return data;
  }
}
